@@ -796,8 +796,6 @@ class HDUList(list, _Verify):
         if 'EXTEND' in hdr:
             if len(self) > 1 and hdr['EXTEND'] == False:
                 hdr['EXTEND'] = True
-            elif len(self) == 1 and hdr['EXTEND'] == True:
-                hdr['EXTEND'] = False
         elif len(self) > 1:
             if hdr['NAXIS'] == 0:
                 hdr.update('EXTEND', True, after='NAXIS')
@@ -929,7 +927,7 @@ class HDUList(list, _Verify):
         results = ['Filename: %s' % name,
                    'No.    Name         Type      Cards   Dimensions   Format']
 
-        format = '%-3d  %-10s  %-11s  %5d   %-10s   %s%s'
+        format = '%-3d  %-10s  %-11s  %5d   %-10s   %s   %s'
         default = ('', '', 0, '()', '', '')
         for idx, hdu in enumerate(self):
             summary = hdu._summary()
