@@ -1,5 +1,8 @@
+import numpy as np
+
 import pyfits
 
+from pyfits.card import _pad
 from pyfits.tests import PyfitsTestCase
 
 from nose.tools import assert_equal, assert_false, assert_raises, assert_true
@@ -39,6 +42,51 @@ class TestHeaderFunctions(PyfitsTestCase):
         assert_equal(str(header[1:3]).rstrip(),
                      'HISTORY ' + longval[:72] + '\nHISTORY ' + longval[72:])
 
+    def test_wildcard_slice(self):
+        """Test selecting a subsection of a header via wildcard matching."""
+
+        header = pyfits.Header()
+        header.update('ABC', 0)
+        header.update('DEF', 1)
+        header.update('ABD', 2)
+        cards = header.ascard['AB*']
+        assert_equal(len(cards), 2)
+        assert_equal(cards[0].value, 0)
+        assert_equal(cards[1].value, 2)
+
+    def test_assign_boolean(self):
+        """
+        Regression test for #123. Tests assigning Python and Numpy boolean
+        values to keyword values.
+        """
+
+        fooimg = _pad('FOO     =                    T')
+        barimg = _pad('BAR     =                    F')
+        h = pyfits.Header()
+        h.update('FOO', True)
+        h.update('BAR', False)
+        assert_equal(h['FOO'], True)
+        assert_equal(h['BAR'], False)
+        assert_equal(h.ascard['FOO'].cardimage, fooimg)
+        assert_equal(h.ascard['BAR'].cardimage, barimg)
+
+        h = pyfits.Header()
+        h.update('FOO', np.bool_(True))
+        h.update('BAR', np.bool_(False))
+        assert_equal(h['FOO'], True)
+        assert_equal(h['BAR'], False)
+        assert_equal(h.ascard['FOO'].cardimage, fooimg)
+        assert_equal(h.ascard['BAR'].cardimage, barimg)
+
+        h = pyfits.Header()
+        h.ascard.append(pyfits.Card.fromstring(fooimg))
+        h.ascard.append(pyfits.Card.fromstring(barimg))
+        assert_equal(h['FOO'], True)
+        assert_equal(h['BAR'], False)
+        assert_equal(h.ascard['FOO'].cardimage, fooimg)
+        assert_equal(h.ascard['BAR'].cardimage, barimg)
+
+
 
 class TestRecordValuedKeywordCards(PyfitsTestCase):
     """Tests for handling of record-valued keyword cards as used by the FITS
